#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author   : tingbai
# @Time     : 2023/2/3 23:49
# @File     : plugin.py
# @Project  : PyCharm

class Plugin:
    pass


def plugins():
    return ["pytest_mini.fixture"]
